==> bio3d_2.1-2.tar.gz: bio3d/R/aa2mass.R <==
"aa2mass" <-
  function(pdb, inds=NULL, mass.custom=NULL, addter=TRUE, mmtk=FALSE) {

    if (missing(pdb))
      stop("must supply 'pdb' object or vector of amino acid residue names")

    if(is.pdb(pdb)) {
      if(!is.null(inds)) {
        pdb <- trim.pdb(pdb, inds)
      }
      sequ <- pdb$atom[pdb$calpha,"resid"]
    }
    else {
      if(!is.null(inds))
        warning("'inds' has no effect when 'pdb' is vector")
      sequ <- pdb
      if(any(nchar(sequ)==1))
        sequ <- aa123(sequ)
      if(any(nchar(sequ)!=3))
        stop("must supply 'pdb' object or vector of amino acid residue names")
    }

    ## Define residues masses
    if(mmtk) {
      ## MMTK (for reproduction purposes!)
      w <- c( 71.079018, 157.196106, 114.104059, 114.080689, 103.143407,
             128.131048, 128.107678,  57.05203,  137.141527, 113.159985,
             113.159985, 129.18266,  131.197384, 147.177144,  97.117044,
              87.078323, 101.105312, 186.213917, 163.176449,  99.132996)
      
      aa <- c("ALA", "ARG", "ASN", "ASP", "CYS",
              "GLN", "GLU", "GLY", "HIS", "ILE",
              "LEU", "LYS", "MET", "PHE", "PRO",
              "SER", "THR", "TRP", "TYR", "VAL")

      mat <- data.frame(aa3=aa, aa1=aa321(aa), aaMass=w, name=NA, formula=NA)
      rownames(mat) <- aa
    }
    else  {
      ## Read data matrix
      #mat.file <- system.file(paste("matrices/aa_mass.mat",sep=""), package="bio3d")
      #mat <- read.table(mat.file)
      mat <- bio3d::aa.mass
      ##return(mat)
    }
    
    ## Data frame with column names:
    ## aa3, aa1, aaMass, name, formula
    if (!is.null(mass.custom)) {
      if(class(mass.custom)!="list")
        stop("'mass.custom' must be of class 'list'")
      
      new.aas <- names(mass.custom)
      if(any(duplicated(new.aas)) ||
         any(new.aas %in% mat[,"aa3"]))
        warning("duplicate residue name(s) provided")
      
      for(new.aa in new.aas) {
        if( new.aa %in% rownames(mat) ) {
          mat[new.aa, "aaMass"] = mass.custom[[ new.aa ]]
        }
        else {
          nr <- data.frame(list(aa3=new.aa, aa1="X",
                                aaMass=mass.custom[[ new.aa ]],
                                name=NA, formula=NA))
          rownames(nr) <- new.aa
          mat <- rbind(mat, nr)
        }
      }
    }

    ## Fetch mass from data frame
    wts <- mat[sequ,"aaMass"]

    ## Check for missing masses
    if(NA%in%wts) {
      inds <- which(wts%in%NA)
      unknown <- paste(unique(sequ[inds]), collapse=" ")
      stop(paste("Unknown aminoacid identifier: ", unknown, sep=""))
    }
    
    if(addter) {
      wts[1] <- wts[1] + atom2mass("H")
      wts[length(wts)] <- wts[length(wts)] + atom2mass("O") + atom2mass("H")
    }
    return(wts)
  }

==> bio3d_2.3-4.tar.gz: bio3d/R/aa2mass.R <==
"aa2mass" <-
  function(pdb, inds=NULL, mass.custom=NULL, addter=TRUE, mmtk=FALSE) {

    if (missing(pdb))
      stop("must supply 'pdb' object or vector of amino acid residue names")

    if(is.pdb(pdb)) {
      if(!is.null(inds)) {
        pdb <- trim.pdb(pdb, inds)
      }
      sequ <- pdb$atom[pdb$calpha,"resid"]
    }
    else {
      if(!is.null(inds))
        warning("'inds' has no effect when 'pdb' is vector")
      sequ <- pdb
      if(any(nchar(sequ)==1))
        sequ <- aa123(sequ)
      if(any(nchar(sequ)!=3))
        stop("must supply 'pdb' object or vector of amino acid residue names")
    }

    ## Define residues masses
    if(mmtk) {
      ## MMTK (for reproduction purposes!)
      w <- c( 71.079018, 157.196106, 114.104059, 114.080689, 103.143407,
             128.131048, 128.107678,  57.05203,  137.141527, 113.159985,
             113.159985, 129.18266,  131.197384, 147.177144,  97.117044,
              87.078323, 101.105312, 186.213917, 163.176449,  99.132996)
      
      aa <- c("ALA", "ARG", "ASN", "ASP", "CYS",
              "GLN", "GLU", "GLY", "HIS", "ILE",
              "LEU", "LYS", "MET", "PHE", "PRO",
              "SER", "THR", "TRP", "TYR", "VAL")

      mat <- data.frame(aa3=aa, aa1=aa321(aa), mass=w, formula=NA, name=NA)
      rownames(mat) <- aa
    }
    else  {
      ## Read data matrix
      mat <- bio3d::aa.table
    }
    
    ## Data frame with column names: aa3, aa1, mass, formula, name
    if (!is.null(mass.custom)) {
      if(class(mass.custom) != "list")
        stop("'mass.custom' must be of class 'list'")
      
      new.aas <- names(mass.custom)
      if(any(duplicated(new.aas))) {
        mass.custom[duplicated(new.aas)] <- NULL
        warning("duplicate residue name(s) in 'mass.custom'. using first occurrence(s) only.")
      }

      new.aas <- names(mass.custom)
      if(any(new.aas %in% mat$aa3)) {
        dups <- paste(unique(new.aas[new.aas %in% mat$aa3]), collapse=", ")
        warning(paste("residue name(s)", dups,
                      "exists in 'aa.table'. overwriting with provided value(s)."))
      }
      
      for(new.aa in new.aas) {
        if( new.aa %in% rownames(mat) ) {
          ## Replace residue mass
          mat[new.aa, "mass"] = mass.custom[[ new.aa ]]
        }
        else {
          ## Add new residue to data frame (aa.table)
          nr <- data.frame(list(aa3=new.aa, aa1="X",
                                mass=mass.custom[[ new.aa ]],
                                formula=NA, name=NA))
          rownames(nr) <- new.aa
          mat <- rbind(mat, nr)
        }
      }
    }

    ## Fetch mass from data frame
    wts <- mat[sequ, "mass"]
    
    ## Check for missing masses
    if(NA %in% wts) {
      inds <- which(wts %in% NA)
      unknown <- paste(unique(sequ[inds]), collapse=" ")
      stop(paste("Unknown amino acid identifier: ", unknown, sep=""))
    }
    
    if(addter) {
      wts[1] <- wts[1] + atom2mass("H")
      wts[length(wts)] <- wts[length(wts)] + atom2mass("O") + atom2mass("H")
    }
    return(wts)
  }
